@@ -4,8 +4,7 @@ except ImportError:
     import Queue as queue
 
 from elasticsearch_raven import configuration
-from elasticsearch_raven.transport import ElasticsearchTransport
-from elasticsearch_raven.transport import SentryMessage
+from elasticsearch_raven import transport
 from elasticsearch_raven.udp_server import get_sender
 
 
@@ -15,9 +14,9 @@ class HttpUtils:
         self._exception_queue = queue.Queue()
 
     def start_sender(self):
-        transport = ElasticsearchTransport(configuration['host'],
-                                           configuration['use_ssl'])
-        sender = get_sender(transport, self._pending_logs, self._exception_queue)
+        log_transport = transport.get_configured_log_transport()
+        sender = get_sender(log_transport, self._pending_logs,
+                            self._exception_queue)
         sender.start()
 
     def get_application(self):
@@ -30,7 +29,7 @@ class HttpUtils:
                 raise exception
             length = int(environ.get('CONTENT_LENGTH', '0'))
             data = environ['wsgi.input'].read(length)
-            self._pending_logs.put(SentryMessage.create_from_http(
+            self._pending_logs.put(transport.SentryMessage.create_from_http(
                 environ['HTTP_X_SENTRY_AUTH'], data))
 
             status = '200 OK'
